pub async fn bootstrap_metadata(client: &mut Client) -> Result<(), ApplyError>Expand description
Create the pgevolve schema and run any pending bootstrap migrations.
Takes &mut Client because each bootstrap migration runs in its own
tokio_postgres::Transaction, which requires exclusive access.